# CliMetLab Web

A web application to manage the cache content and configuration settings of the [CliMetLab](https://github.com/ecmwf/climetlab) Python package.

## Installation

Installation in a virtual environment is advised.

```
pip install climetlab-script-web
```

## Contributing

See `CONTRIBUTING.md`.

# Licence

Apache License 2.0 In applying this licence, ECMWF does not waive the privileges and immunities granted to it by virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.
